@@ -1,7 +1,6 @@
 import re
 from string import punctuation
 from datetime import datetime
-import pytz
 import json
 import sys
 
@@ -12,11 +11,10 @@ punct = frozenset(punctuation)
 
 def now(dt=False):
 	d = datetime.utcnow()
-	utc = d.replace(tzinfo=pytz.utc)
 	if dt:
-		return utc
+		return d
 	else:
-		return int(utc.strftime('%s'))
+		return int(d.strftime('%s'))
 
 
 def rm_punct(s):
